import logging

from typing import Optional

from .api import event, task_event
from .appliance import min_ppa_version
from .exceptions import EventNotConfigured, AuthenticationFailed


logger = logging.getLogger(__name__)


@min_ppa_version("3.0.0")
@task_event()
def has_mfa(text: str) -> bool:
    return event("user/has_mfa", text)


@min_ppa_version("3.0.0")
@task_event({204: EventNotConfigured, 401: AuthenticationFailed})
def prompt_mfa(text: str, element_id: Optional[str] = None, sensitive: Optional[bool] = None) -> bool:
    return event("user/mfa", text, id=element_id, obfuscate=sensitive)
